pub trait ExecuteMsgFns<Chain: TxHandler, CwOrchExecuteMsgType>: CwOrchExecute<Chain, ExecuteMsg = CwOrchExecuteMsgType>where
ExecuteMsg: Into<CwOrchExecuteMsgType>,{
// Provided method
fn proxy(
&self,
msgs: Vec<CosmosMsg>,
) -> Result<TxResponse<Chain>, CwEnvError> { ... }
}Expand description
Automatically derived trait that allows you to call the variants of the message directly without the need to construct the struct yourself.
Provided Methods
Sourcefn proxy(&self, msgs: Vec<CosmosMsg>) -> Result<TxResponse<Chain>, CwEnvError>
fn proxy(&self, msgs: Vec<CosmosMsg>) -> Result<TxResponse<Chain>, CwEnvError>
Automatically generated wrapper around ExecuteMsg::Proxy variant
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl<Chain: TxHandler, CwOrchExecuteMsgType, SupportedContract> ExecuteMsgFns<Chain, CwOrchExecuteMsgType> for SupportedContractwhere
ExecuteMsg: Into<CwOrchExecuteMsgType>,
SupportedContract: CwOrchExecute<Chain, ExecuteMsg = CwOrchExecuteMsgType>,
Available on non-WebAssembly only.