pub trait AsyncQueryMsgFns<Chain: AsyncWasmQuerier + ChainState, CwOrchQueryMsgType: Sync>: AsyncCwOrchQuery<Chain, QueryMsg = CwOrchQueryMsgType>{
// Provided method
async fn instantiator_async(&self) -> Result<Addr, CwEnvError> { ... }
}Expand description
Automatically derived trait that allows you to call the variants of the message directly without the need to construct the struct yourself.
Provided Methods
Sourceasync fn instantiator_async(&self) -> Result<Addr, CwEnvError>
async fn instantiator_async(&self) -> Result<Addr, CwEnvError>
Automatically generated wrapper around QueryMsg::Instantiator variant
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl<Chain: AsyncWasmQuerier + ChainState, CwOrchQueryMsgType: Sync, SupportedContract> AsyncQueryMsgFns<Chain, CwOrchQueryMsgType> for SupportedContractwhere
QueryMsg: Into<CwOrchQueryMsgType>,
SupportedContract: AsyncCwOrchQuery<Chain, QueryMsg = CwOrchQueryMsgType>,
Available on non-WebAssembly only.