pub trait QueryMsgFns<Chain: QueryHandler + ChainState, CwOrchQueryMsgType>: CwOrchQuery<Chain, QueryMsg = CwOrchQueryMsgType>{
// Provided method
fn instantiator(&self) -> Result<Addr, CwEnvError> { ... }
}Expand description
Automatically derived trait that allows you to call the variants of the message directly without the need to construct the struct yourself.
Provided Methods
Sourcefn instantiator(&self) -> Result<Addr, CwEnvError>
fn instantiator(&self) -> Result<Addr, CwEnvError>
Automatically generated wrapper around QueryMsg::Instantiator variant
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl<Chain: QueryHandler + ChainState, CwOrchQueryMsgType, SupportedContract> QueryMsgFns<Chain, CwOrchQueryMsgType> for SupportedContractwhere
QueryMsg: Into<CwOrchQueryMsgType>,
SupportedContract: CwOrchQuery<Chain, QueryMsg = CwOrchQueryMsgType>,
Available on non-WebAssembly only.